@@ -1,9 +1,11 @@
 pub mod cargo;
+pub mod maven;
 pub mod meson;
 pub mod setuptools;
 pub mod yarn;
 
 pub(crate) use cargo::*;
+pub(crate) use maven::*;
 pub(crate) use meson::*;
 pub(crate) use setuptools::*;
 pub(crate) use yarn::*;
